![API](https://badgen.net/badge/API/24+/green)
# SoundAura

SoundAura is an open source ambient sound app. It does not include any audio
tracks to save on download size, but allows users to add local files from
their device and play any (reasonable) number of them concurrently, with
individual volume controls for each track. SoundAura can also switch between
an audio focus respecting mode, and a 'play in background' mode that ignores
audio focus rules and allows SoundAura to play audio alongside other apps.
  
SoundAura is built using:
- Kotlin
- MVVM paradigm (though without a repository layer due to there being only one data source)
- Room persistence library and Jetpack DataStore for the data
- Jetpack Compose for the UI
- Hilt for dependency injection
- Junit and Robolectric for testing

[<img src="https://fdroid.gitlab.io/artwork/badge/get-it-on.png"
     alt="Get it on F-Droid"
     height="80">](https://f-droid.org/packages/com.cliffracertech.soundaura/)

## Features
- A library of user-added tracks based on the device's local files.
- Individual track volume control
- A media notification to control playback when the app is in the background.
  These controls will appear with other media session controls if 'play in
  background' is turned off, or as a regular notification when 'play in
  background' is turned on.
- A quick settings tile to control playback. If the quick settings tile
  is in use, the notification can be manually hidden if desired to save
  notification space.
- Auto-pause during calls. If SoundAura is respecting audio focus rules,
  then auto-pausing during phone calls will happen automatically due to
  the app losing audio focus. If audio focus is ignored due to 'play in
  background' being turned on, SoundAura requires the read phone state
  permission to be able to detect when a phone call is ongoing. Auto-pause
  during calls is toggled on in the app settings if the 'play in
  background' setting is turned on.
- Auto-pause on audio device changes: If SoundAura is playing, and an
  audio device change occurs that results in a system media volume of
  zero (e.g. the user unplugs or disconnects their headphones and the
  device's media volume is zero for its speaker), SoundAura will auto-pause
  its playback since it can't be heard anyways. If another audio device
  change occurs that makes the media volume go above zero, SoundAura
  will also automatically unpause itself unless the user manually
  affected the playback state in the mean time.
- No permissions required, except the read phone state permission for the
  optional auto-pause during calls when 'play in background' is turned on.

## Screenshots

https://user-images.githubusercontent.com/42116365/192111969-21b03711-e844-47c2-a637-54f3917c5f9d.mp4

<p float="left">
  <img src="metadata/en-US/images/phoneScreenshots/1.png" width="200" height="434">
  <img src="metadata/en-US/images/phoneScreenshots/2.png" width="200" height="434">
  <img src="metadata/en-US/images/phoneScreenshots/3.png" width="200" height="434">
  <img src="metadata/en-US/images/phoneScreenshots/4.png" width="200" height="434">
</p>

## Privacy Policy
SoundAura does not collect, store, or transmit any personal information.

## License
SoundAura's source code is released under the terms of the Apache License,
version 2.0. See the file 'license' in the repository's root directory to
see the full license text.
